From: "Daniel P. Berrangé" <berrange@redhat.com>
To: qemu-devel@nongnu.org
Cc: "Manos Pitsidianakis" <manos.pitsidianakis@linaro.org>,
"Hanna Reitz" <hreitz@redhat.com>,
"Marc-André Lureau" <marcandre.lureau@redhat.com>,
"Kevin Wolf" <kwolf@redhat.com>,
"Philippe Mathieu-Daudé" <philmd@linaro.org>,
"Dr. David Alan Gilbert" <dave@treblig.org>,
devel@lists.libvirt.org, "Stefan Weil" <sw@weilnetz.de>,
qemu-block@nongnu.org, "Paolo Bonzini" <pbonzini@redhat.com>,
"Markus Armbruster" <armbru@redhat.com>,
"Daniel P. Berrangé" <berrange@redhat.com>
Subject: [PATCH 08/12] util: convert error-report & log to message API for timestamp
Date: Tue, 19 Aug 2025 21:27:04 +0100 [thread overview]
Message-ID: <20250819202708.1185594-9-berrange@redhat.com> (raw)
In-Reply-To: <20250819202708.1185594-1-berrange@redhat.com>
Both the error-report and log APIs can optional emit a timestamp
as a prefix on messages, with the '-msg timestamp=on' command
line flag is set.
Convert them to the new message API for formatting the context
prefix, guaranteeign they will have matching behaviour going
forward.
There is no change in output format for either logs or errors
with this conversion.
Signed-off-by: Daniel P. Berrangé <berrange@redhat.com>
---
include/qemu/error-report.h | 1 -
system/vl.c | 7 ++++++-
tests/unit/test-error-report.c | 3 ++-
util/error-report.c | 18 +++---------------
util/log.c | 20 +++++++-------------
5 files changed, 18 insertions(+), 31 deletions(-)
diff --git a/include/qemu/error-report.h b/include/qemu/error-report.h
index 3ae2357fda..c8000778ec 100644
--- a/include/qemu/error-report.h
+++ b/include/qemu/error-report.h
@@ -70,7 +70,6 @@ void error_init(const char *argv0);
fmt, ##__VA_ARGS__); \
})
-extern bool message_with_timestamp;
extern bool error_with_guestname;
extern const char *error_guest_name;
diff --git a/system/vl.c b/system/vl.c
index a64fd90d4a..696dd92669 100644
--- a/system/vl.c
+++ b/system/vl.c
@@ -26,6 +26,7 @@
#include "qemu/help-texts.h"
#include "qemu/datadir.h"
#include "qemu/units.h"
+#include "qemu/message.h"
#include "qemu/module.h"
#include "qemu/target-info.h"
#include "exec/cpu-common.h"
@@ -813,8 +814,12 @@ static void realtime_init(void)
static void configure_msg(QemuOpts *opts)
{
- message_with_timestamp = qemu_opt_get_bool(opts, "timestamp", false);
+ int flags = 0;
+ if (qemu_opt_get_bool(opts, "timestamp", false)) {
+ flags |= QMESSAGE_FORMAT_TIMESTAMP;
+ }
error_with_guestname = qemu_opt_get_bool(opts, "guest-name", false);
+ qmessage_set_format(flags);
}
diff --git a/tests/unit/test-error-report.c b/tests/unit/test-error-report.c
index 54319c86c9..78f8b57660 100644
--- a/tests/unit/test-error-report.c
+++ b/tests/unit/test-error-report.c
@@ -13,6 +13,7 @@
#include "qemu/error-report.h"
#include "qapi/error.h"
+#include "qemu/message.h"
static void
test_error_report_simple(void)
@@ -90,7 +91,7 @@ static void
test_error_report_timestamp(void)
{
if (g_test_subprocess()) {
- message_with_timestamp = true;
+ qmessage_set_format(QMESSAGE_FORMAT_TIMESTAMP);
warn_report("warn");
error_report("err");
return;
diff --git a/util/error-report.c b/util/error-report.c
index 1b17c11de1..932af5d9f5 100644
--- a/util/error-report.c
+++ b/util/error-report.c
@@ -13,6 +13,7 @@
#include "qemu/osdep.h"
#include "monitor/monitor.h"
#include "qemu/error-report.h"
+#include "qemu/message.h"
/*
* @report_type is the type of message: error, warning or
@@ -24,8 +25,6 @@ typedef enum {
REPORT_TYPE_INFO,
} report_type;
-/* Prepend timestamp to messages */
-bool message_with_timestamp;
bool error_with_guestname;
const char *error_guest_name;
@@ -169,13 +168,6 @@ static void print_loc(void)
}
}
-static char *
-real_time_iso8601(void)
-{
- g_autoptr(GDateTime) dt = g_date_time_new_now_utc();
- return g_date_time_format_iso8601(dt);
-}
-
/*
* Print a message to current monitor if we have one, else to stderr.
* @report_type is the type of message: error, warning or informational.
@@ -186,13 +178,9 @@ real_time_iso8601(void)
G_GNUC_PRINTF(2, 0)
static void vreport(report_type type, const char *fmt, va_list ap)
{
- gchar *timestr;
+ g_autofree gchar *context = qmessage_context(QMESSAGE_CONTEXT_SKIP_MONITOR);
- if (message_with_timestamp && !monitor_cur()) {
- timestr = real_time_iso8601();
- error_printf("%s ", timestr);
- g_free(timestr);
- }
+ error_printf("%s", context);
/* Only prepend guest name if -msg guest-name and -name guest=... are set */
if (error_with_guestname && error_guest_name && !monitor_cur()) {
diff --git a/util/log.c b/util/log.c
index abdcb6b311..435d1c7135 100644
--- a/util/log.c
+++ b/util/log.c
@@ -22,6 +22,7 @@
#include "qemu/range.h"
#include "qemu/error-report.h"
#include "qapi/error.h"
+#include "qemu/message.h"
#include "qemu/cutils.h"
#include "trace/control.h"
#include "qemu/thread.h"
@@ -146,26 +147,19 @@ void qemu_log_unlock(FILE *logfile)
void qemu_log(const char *fmt, ...)
{
FILE *f;
- g_autofree const char *timestr = NULL;
-
/*
* Prepare the timestamp *outside* the logging
* lock so it better reflects when the message
* was emitted if we are delayed acquiring the
* mutex
*/
- if (message_with_timestamp) {
- g_autoptr(GDateTime) dt = g_date_time_new_now_utc();
- timestr = g_date_time_format_iso8601(dt);
- }
+ g_autofree const char *context = qmessage_context(0);
f = qemu_log_trylock();
if (f) {
va_list ap;
- if (timestr) {
- fprintf(f, "%s ", timestr);
- }
+ fwrite(context, 1, strlen(context), f);
va_start(ap, fmt);
vfprintf(f, fmt, ap);
@@ -146,26 +147,19 @@ void qemu_log_unlock(FILE *logfile)
/*
- * Prepare the timestamp *outside* the logging
- * lock so it better reflects when the message
- * was emitted if we are delayed acquiring the
- * mutex
+ * Prepare the context *outside* the logging
+ * lock so any timestamp better reflects when
+ * the message was emitted if we are delayed
+ * acquiring the mutex
*/
--
2.50.1
next prev parent reply other threads:[~2025-08-19 20:29 UTC|newest]
Thread overview: 26+ messages / expand[flat|nested] mbox.gz Atom feed top
2025-08-19 20:26 [PATCH 00/12] util: sync error_report & qemu_log output more closely Daniel P. Berrangé
2025-08-19 20:26 ` [PATCH 01/12] include: define constant for early constructor priority Daniel P. Berrangé
2025-08-19 20:26 ` [PATCH 02/12] monitor: initialize global data from a constructor Daniel P. Berrangé
2025-08-19 20:26 ` [PATCH 03/12] system: unconditionally enable thread naming Daniel P. Berrangé
2025-08-19 22:00 ` Dr. David Alan Gilbert
2025-08-19 20:27 ` [PATCH 04/12] util: set the name for the 'main' thread Daniel P. Berrangé
2025-08-19 23:18 ` Dr. David Alan Gilbert
2025-08-20 10:29 ` Daniel P. Berrangé
2025-08-19 20:27 ` [PATCH 05/12] util: add API to fetch the current thread id Daniel P. Berrangé
2025-08-19 21:38 ` Richard Henderson
2025-08-19 23:35 ` Dr. David Alan Gilbert
2025-08-20 10:47 ` Daniel P. Berrangé
2025-08-19 20:27 ` [PATCH 06/12] util: add API to fetch the current thread name Daniel P. Berrangé
2025-08-19 21:50 ` Richard Henderson
2025-08-20 10:50 ` Daniel P. Berrangé
2025-08-19 20:27 ` [PATCH 07/12] util: introduce common helper for error-report & log code Daniel P. Berrangé
2025-08-19 21:57 ` Richard Henderson
2025-08-20 11:00 ` Daniel P. Berrangé
2025-08-19 20:27 ` Daniel P. Berrangé [this message]
2025-08-19 22:02 ` [PATCH 08/12] util: convert error-report & log to message API for timestamp Richard Henderson
2025-08-20 11:12 ` Daniel P. Berrangé
2025-08-29 18:07 ` Daniel P. Berrangé
2025-08-19 20:27 ` [PATCH 09/12] util: add support for formatting a workload name in messages Daniel P. Berrangé
2025-08-19 20:27 ` [PATCH 10/12] util: add support for formatting a program " Daniel P. Berrangé
2025-08-19 20:27 ` [PATCH 11/12] util: add support for formatting thread info " Daniel P. Berrangé
2025-08-19 20:27 ` [PATCH 12/12] util: add brackets around guest name in message context Daniel P. Berrangé
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20250819202708.1185594-9-berrange@redhat.com \
--to=berrange@redhat.com \
--cc=armbru@redhat.com \
--cc=dave@treblig.org \
--cc=devel@lists.libvirt.org \
--cc=hreitz@redhat.com \
--cc=kwolf@redhat.com \
--cc=manos.pitsidianakis@linaro.org \
--cc=marcandre.lureau@redhat.com \
--cc=pbonzini@redhat.com \
--cc=philmd@linaro.org \
--cc=qemu-block@nongnu.org \
--cc=qemu-devel@nongnu.org \
--cc=sw@weilnetz.de \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.